﻿using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.DirectX.DirectSound;
using System.Windows.Forms;

namespace WiiSaber
{
    public class DXSoundControl
    {
        private Device dev = null;

        public SecondaryBuffer GetFileBuffer(string fileName)
        {
            SecondaryBuffer buffer;
            if (this.dev == null)
            {
                throw new Exception("DirectSound device not initialized!");
            }
            try
            {
                BufferDescription desc = new BufferDescription();
                desc.Flags = BufferDescriptionFlags.GlobalFocus | BufferDescriptionFlags.ControlVolume;
                SecondaryBuffer buffer2 = new SecondaryBuffer(fileName, desc, this.dev);
                buffer = buffer2;
            }
            catch (Exception exception1)
            {
                Exception exception = exception1;
                buffer = null;
            }
            return buffer;
        }

        public void InitializeDirectSound(Control ownerControl)
        {
            try
            {
                this.dev = new Device();
                this.dev.SetCooperativeLevel(ownerControl, CooperativeLevel.Priority);
            }
            catch (Exception exception1)
            {
                Exception exception = exception1;
                MessageBox.Show("Unable to create sound device: " + exception.Message, "Error");
            }
        }

        public void PlayObject(FXObject fxObj, double volumePercent)
        {
            //fxObj.SecondaryBuffer.Volume = GetVolumeValueFromPercentage(volumePercent);

            if (fxObj.SecondaryBuffer == null)
            {
                throw new Exception("Secondary buffer does not exist.");
            }
            if (fxObj.SecondaryBuffer.Status.Playing)
            {
                fxObj.SecondaryBuffer.Stop();
                fxObj.SecondaryBuffer.SetCurrentPosition(0);
            }
            if (fxObj.LoopEnabled)
            {
                fxObj.SecondaryBuffer.Play(0, BufferPlayFlags.Looping);
            }
            else
            {
                fxObj.SecondaryBuffer.Play(0, BufferPlayFlags.Default);
            }
        }

        public void ChangeVolume(FXObject fxObj, double volumePercent)
        {
            if (fxObj.SecondaryBuffer == null)
            {
                throw new Exception("Secondary buffer does not exist.");
            }

            fxObj.SecondaryBuffer.Volume = GetVolumeValueFromPercentage(volumePercent);
        }

        public int GetVolumeValueFromPercentage(double percent)
        {
            // min value -10000, max value 0
            double effectivePercent = 0 - ((100-percent) * 100);

            return Convert.ToInt32(effectivePercent);
        }

        public void StopObject(FXObject fxObj)
        {
            if (fxObj.SecondaryBuffer == null)
            {
                throw new Exception("Secondary buffer does not exist.");
            }
            fxObj.SecondaryBuffer.Stop();
        }
    }
}
