﻿using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.DirectX.DirectSound;
using System.Windows.Forms;
using System.IO;

namespace WiiSaber
{
    public class SaberSoundController
    {
        private DXSoundControl dxSoundController = null;
        public SaberSoundController(Control appOwnerControl)
        {
            dxSoundController = new DXSoundControl();
            dxSoundController.InitializeDirectSound(appOwnerControl);

            InitSounds();
        }

        private FXObject saberConstantHum;
        private FXObject saberSwingHum;
        
        private void InitSounds()
        {
            saberConstantHum = new FXObject(dxSoundController);
            saberConstantHum.FileName = new FileInfo(".\\Sounds\\SaberConstantHum.wav").FullName;
            saberConstantHum.LoopEnabled = true;

            saberSwingHum = new FXObject(dxSoundController);
            saberSwingHum.FileName = new FileInfo(".\\Sounds\\SaberSwingHum.wav").FullName;
            saberSwingHum.LoopEnabled = true;
        }

        public void TurnOnLightsaber(double constantHumVolumePercent)
        {
            dxSoundController.PlayObject(saberConstantHum, constantHumVolumePercent);
            dxSoundController.PlayObject(saberSwingHum, 0);

            SetConstantHumVolumePercent(constantHumVolumePercent);
            SetSwingIntensity(0);
        }

        public void TurnOffLightsaber()
        {
            dxSoundController.StopObject(saberConstantHum);
            dxSoundController.StopObject(saberSwingHum);
        }

        public void SetSwingIntensity(double intensityPercent)
        {
            dxSoundController.ChangeVolume(saberSwingHum, intensityPercent);
        }

        public void SetConstantHumVolumePercent(double volPercent)
        {
            dxSoundController.ChangeVolume(saberConstantHum, volPercent);
        }
    }
}
